searchData={"content_type":"text/markdown","items":[{"doc":"This library aims to simplify the process of sitting an application behind Cloudflare Access.\n\n  By default, this library starts its own supervision tree. The root application will read Application\n  config to determine which Cloudflare Access domains to retrieve JWKs from. These keys can then be used\n  to verify the application tokens sent by Cloudflare Access when your application is accessed.\n\n  The [Cloudflare docs](https://developers.cloudflare.com/cloudflare-one/identity/authorization-cookie/application-token/)\n  provide more information.\n\n  The library also provides a Plug (see `CloudflareAccessEx.Plug`) that can be used to to extract and\n  verify tokens from requests.\n\n  Usage:\n\n  1. Add `cloudflare_access_ex` to your list of dependencies in `mix.exs`. Note that the\n     `:runtime` option can be used to disable Jwks polling in selected environments (i.e. `:test` and `:dev`)\n\n         def deps do\n           [\n             {:cloudflare_access_ex, \"~> 0.1.0\", runtime: Mix.env() not in [:test, :dev]}\n           ]\n         end\n\n     If you wish to startup the application manually, you can opt out of the runtime dependency and start the\n     supervisor manually:\n\n         def deps do\n           [\n             {:cloudflare_access_ex, \"~> 0.1.0\", runtime: false}\n           ]\n         end\n\n     in your application module:\n\n         CloudflareAccessEx.Supervisor.start_link(... TODO ...)\n\n  2. Get the audience tag from the Cloudflare Access dashboard for your application.\n     [Instruction here](https://developers.cloudflare.com/cloudflare-one/identity/authorization-cookie/validating-json/#get-your-aud-tag).\n\n  3. Configure the application:\n\n         config :cloudflare_access_ex, :my_cfa_app,\n             domain: \"example.cloudflareaccess.com\"\n             # this is the audience tag retrieved on step 2\n             audience: \"a8d3b7...\"\n\n     Multiple applications can be configured by adding more keys to the `:cloudflare_access_ex` config. i.e.\n\n         config :cloudflare_access_ex, :my_cfa_app,\n             domain: \"example.cloudflareaccess.com\"\n             audience: \"a8d3b7...\"\n\n         config :cloudflare_access_ex, :my_other_cfa_app,\n             domain: \"example.cloudflareaccess.com\"\n             audience: \"7309b8...\"\n\n     There will only be one process that fetches Jwks keys for each domain. It's also possible to consolidate the\n     duplicate configuration for the domain string like so:\n\n         config :cloudflare_access_ex, :example,\n             domain: \"example.cloudflareaccess.com\"\n\n         config :cloudflare_access_ex, :my_cfa_app,\n             domain: :example, audience: \"a8d3b7...\"\n\n         config :cloudflare_access_ex, :my_other_cfa_app,\n             domain: :example, audience: \"7309b8...\"\n\n  4. Verify tokens either using `CloudflareAccessEx.Plug` (this will return 401 for invalid tokens by default):\n\n         plug CloudflareAccessEx.Plug, cfa_app: :my_cfa_app\n\n     or using `CloudflareAccessEx.AccessTokenVerifier` directly if you need even more control:\n\n         alias CloudflareAccessEx.AccessTokenVerifier\n\n         verifier = AccessTokenVerifier.create(:my_cfa_app)\n         {:ok, token} = conn |> AccessTokenVerifier.verify(verifier)\n\n         case token do\n           :anonymous -> # do something\n           {:user, %{id: _, email: _}} -> # do something else\n         end","ref":"CloudflareAccessEx.html","title":"CloudflareAccessEx","type":"module"},{"doc":"Verifies a Cloudflare Access token (JWT) and returns decoded information from the token.","ref":"CloudflareAccessEx.AccessTokenVerifier.html","title":"CloudflareAccessEx.AccessTokenVerifier","type":"module"},{"doc":"Creates an AccessTokenVerifier that can be used by `AccessTokenVerifier.verify/2`.\n\nIf the config is an atom, it will be used to lookup the config in the `:cloudflare_access_ex` `Application` environment.\n\nAlternatively, the config can be a keyword list with the following keys:\n\n* `:domain` - The domain to verify the token against. This can be a string or an atom that is used to lookup the domain in the `:cloudflare_access_ex` `Application` environment.\n* `:audience` - The audience to verify the token against.\n* `:jwks_strategy` - The module to use to fetch the public keys from Cloudflare's JWKS endpoint. Defaults to `CloudflareAccessEx.JwksStrategy`.","ref":"CloudflareAccessEx.AccessTokenVerifier.html#create/1","title":"CloudflareAccessEx.AccessTokenVerifier.create/1","type":"function"},{"doc":"iex> Application.put_env(:cloudflare_access_ex, :my_cfa_app, [\n    ...>   domain: \"example.com\",\n    ...>   audience: \"audience_string\",\n    ...> ])\n    ...>\n    ...> AccessTokenVerifier.create(:my_cfa_app)\n    %AccessTokenVerifier{\n      audience: \"audience_string\",\n      domain: \"example.com\",\n      issuer: \"https://example.com\",\n      jwks_strategy: CloudflareAccessEx.JwksStrategy\n    }\n\n    iex> Application.put_env(:cloudflare_access_ex, :my_cfa_app, [\n    ...>   domain: :example,\n    ...>   audience: \"audience_string\",\n    ...> ])\n    ...> Application.put_env(:cloudflare_access_ex, :example,\n    ...>   domain: \"example.com\"\n    ...> )\n    ...>\n    ...> AccessTokenVerifier.create(:my_cfa_app)\n    %AccessTokenVerifier{\n      audience: \"audience_string\",\n      domain: \"example.com\",\n      issuer: \"https://example.com\",\n      jwks_strategy: CloudflareAccessEx.JwksStrategy\n    }\n\n    iex> AccessTokenVerifier.create(\n    ...>   domain: \"example.com\",\n    ...>   audience: \"audience_string\",\n    ...>   jwks_strategy: MyCustomJwksStrategy\n    ...> )\n    %AccessTokenVerifier{\n      audience: \"audience_string\",\n      domain: \"example.com\",\n      issuer: \"https://example.com\",\n      jwks_strategy: MyCustomJwksStrategy\n    }","ref":"CloudflareAccessEx.AccessTokenVerifier.html#create/1-examples","title":"Examples - CloudflareAccessEx.AccessTokenVerifier.create/1","type":"function"},{"doc":"Verifies the authenticity of the Cloudflare Access token in the given `Plug.Conn` or access_token against the given verifier.","ref":"CloudflareAccessEx.AccessTokenVerifier.html#verify/2","title":"CloudflareAccessEx.AccessTokenVerifier.verify/2","type":"function"},{"doc":"","ref":"CloudflareAccessEx.AccessTokenVerifier.html#t:t/0","title":"CloudflareAccessEx.AccessTokenVerifier.t/0","type":"opaque"},{"doc":"","ref":"CloudflareAccessEx.AccessTokenVerifier.html#t:verified_token/0","title":"CloudflareAccessEx.AccessTokenVerifier.verified_token/0","type":"type"},{"doc":"","ref":"CloudflareAccessEx.AccessTokenVerifier.html#t:verify_result/0","title":"CloudflareAccessEx.AccessTokenVerifier.verify_result/0","type":"type"},{"doc":"Utility functions for processing the configuration of the library.","ref":"CloudflareAccessEx.Config.html","title":"CloudflareAccessEx.Config","type":"module"},{"doc":"Return all domain names in all keys under :cloudflare_access_ex.","ref":"CloudflareAccessEx.Config.html#get_domain_strings/0","title":"CloudflareAccessEx.Config.get_domain_strings/0","type":"function"},{"doc":"Get the issuer URL for a domain. By default, just the domain name is provided, but it\nis also possible to provide a full URL. This function will ensure that the issuer URL\nis a full URL.","ref":"CloudflareAccessEx.Config.html#get_issuer/1","title":"CloudflareAccessEx.Config.get_issuer/1","type":"function"},{"doc":"Given a domain atom or string, return the domain string.\n\nIf the domain is an atom, it will be looked up in the application config.","ref":"CloudflareAccessEx.Config.html#resolve_domain/1","title":"CloudflareAccessEx.Config.resolve_domain/1","type":"function"},{"doc":"This module is responsible for fetching and caching the public keys from Cloudflare's JWKS endpoint.\n\n  The keys are fetched on startup and then every hour after that.\n\n  The module implements JokenJwks's SignerMatchStrategy behaviour which is used by the JokenJwks hook to attempt to\n  retrieve the correct signer to verify the token given the kid (key id) in the token header.","ref":"CloudflareAccessEx.JwksStrategy.html","title":"CloudflareAccessEx.JwksStrategy","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"CloudflareAccessEx.JwksStrategy.html#child_spec/1","title":"CloudflareAccessEx.JwksStrategy.child_spec/1","type":"function"},{"doc":"Implementing `SignerMatchStrategy`, attempts to find the `Signer` for the given key ID (`kid`).\n\nExpects `opts` to contain the domain that owns the key.","ref":"CloudflareAccessEx.JwksStrategy.html#match_signer_for_kid/2","title":"CloudflareAccessEx.JwksStrategy.match_signer_for_kid/2","type":"function"},{"doc":"Ensures that the `JwksStrategy` for the given domain has initialized OK and is ready to return signers.","ref":"CloudflareAccessEx.JwksStrategy.html#ready?/1","title":"CloudflareAccessEx.JwksStrategy.ready?/1","type":"function"},{"doc":"","ref":"CloudflareAccessEx.JwksStrategy.html#start_link/1","title":"CloudflareAccessEx.JwksStrategy.start_link/1","type":"function"},{"doc":"","ref":"CloudflareAccessEx.JwksStrategy.html#t:options/0","title":"CloudflareAccessEx.JwksStrategy.options/0","type":"type"},{"doc":"This plug is responsible for verifying the Cloudflare Access JWT token\nand ensuring that it is valid.","ref":"CloudflareAccessEx.Plug.html","title":"CloudflareAccessEx.Plug","type":"module"},{"doc":"plug CloudflareAccessEx.Plug, cfa_app: :my_cfa_app\n\nTo allow anonymous tokens, use the following:\n\n    plug CloudflareAccessEx.Plug, cfa_app: :my_cfa_app, allow_anonymous: true","ref":"CloudflareAccessEx.Plug.html#module-examples","title":"Examples - CloudflareAccessEx.Plug","type":"module"},{"doc":"This function is responsible for verifying the Cloudflare Access JWT token\nIt will reject the request if the token is invalid or if the token is anonymous\nand anonymous access is not allowed.","ref":"CloudflareAccessEx.Plug.html#call/2","title":"CloudflareAccessEx.Plug.call/2","type":"function"},{"doc":"# MIT License\n\nCopyright (c) 2023 Prima.it\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html","title":"License","type":"extras"}]}